@@ -16,6 +16,7 @@ COMMAND_SHUTTER_CLOSE: Final = "ShutterClose"
 COMMAND_SHUTTER_OPEN: Final = "ShutterOpen"
 COMMAND_SHUTTER_POSITION: Final = "ShutterPosition"
 COMMAND_SHUTTER_STOP: Final = "ShutterStop"
+COMMAND_SHUTTER_TILT: Final = "ShutterTilt"
 COMMAND_SPEED: Final = "Speed2"
 COMMAND_WHITE: Final = "White"
 
@@ -36,6 +37,7 @@ CONF_OPTIONS: Final = "so"
 CONF_PREFIX: Final = "tp"
 CONF_SENSOR: Final = "sn"
 CONF_SHUTTER_OPTIONS: Final = "sho"
+CONF_SHUTTER_TILT: Final = "sht"
 CONF_STATE: Final = "state"
 CONF_RELAY: Final = "rl"
 CONF_SW_VERSION: Final = "sw"
@@ -104,6 +106,7 @@ SENSOR_PRESSUREATSEALEVEL: Final = "SeaPressure"
 SENSOR_APPARENT_POWERUSAGE: Final = "ApparentPower"
 SENSOR_BATTERY: Final = "Battery"
 SENSOR_CURRENT: Final = "Current"
+SENSOR_CURRENTNEUTRAL: Final = "CurrentNeutral"
 SENSOR_DISTANCE: Final = "Distance"
 SENSOR_FREQUENCY: Final = "Frequency"
 SENSOR_HUMIDITY: Final = "Humidity"
@@ -118,16 +121,26 @@ SENSOR_PB10: Final = "PB10"
 SENSOR_PM1: Final = "PM1"
 SENSOR_PM2_5: Final = "PM2.5"
 SENSOR_PM10: Final = "PM10"
+SENSOR_CF1: Final = "CF1"
+SENSOR_CF2_5: Final = "CF2.5"
+SENSOR_CF10: Final = "CF10"
+SENSOR_PHASEANGLE: Final = "PhaseAngle"
 SENSOR_POWERFACTOR: Final = "Factor"
 SENSOR_POWERUSAGE: Final = "Power"
 SENSOR_SPEED: Final = "Speed"
 SENSOR_TOTAL_START_TIME: Final = "TotalStartTime"
+SENSOR_ACTIVE_POWERUSAGE: Final = "ActivePower"
 SENSOR_REACTIVE_POWERUSAGE: Final = "ReactivePower"
 SENSOR_TODAY: Final = "Today"
 SENSOR_TOTAL: Final = "Total"
 SENSOR_VOLTAGE: Final = "Voltage"
 SENSOR_WEIGHT: Final = "Weight"
 SENSOR_YESTERDAY: Final = "Yesterday"
+SENSOR_ENERGY: Final = "Energy"
+SENSOR_ACTIVE_ENERGYEXPORT: Final = "ExportActive"
+SENSOR_ACTIVE_ENERGYIMPORT: Final = "ImportActive"
+SENSOR_REACTIVE_ENERGYEXPORT: Final = "ExportReactive"
+SENSOR_REACTIVE_ENERGYIMPORT: Final = "ImportReactive"
 SENSOR_CO2: Final = "CarbonDioxide"
 SENSOR_ECO2: Final = "eCO2"
 SENSOR_TVOC: Final = "TVOC"
@@ -157,6 +170,7 @@ SHUTTER_DIRECTION_DOWN: Final = -1
 SHUTTER_DIRECTION_STOP: Final = 0
 SHUTTER_DIRECTION_UP: Final = 1
 SHUTTER_POSITION: Final = "Position"
+SHUTTER_TILT: Final = "Tilt"
 
 SHUTTER_OPTION_INVERT: Final = 1
 
@@ -180,6 +194,9 @@ TEMP_CELSIUS: Final = "C"
 TEMP_FAHRENHEIT: Final = "F"
 TEMP_KELVIN: Final = "K"
 
+# Degree units
+DEGREE: Final = "°"
+
 # Time units
 TIME_SECONDS: Final = "s"
 TIME_HOURS: Final = "h"
