@@ -13,6 +13,7 @@ from .const import (
     CONF_DEVICENAME,
     CONF_MAC,
     CONF_SENSOR,
+    DEGREE,
     ELECTRICAL_CURRENT_AMPERE,
     ELECTRICAL_VOLT_AMPERE,
     ENERGY_KILO_WATT_HOUR,
@@ -24,18 +25,26 @@ from .const import (
     POWER_WATT,
     PRESSURE_HPA,
     PRESSURE_MMHG,
+    SENSOR_ACTIVE_ENERGYEXPORT,
+    SENSOR_ACTIVE_ENERGYIMPORT,
+    SENSOR_ACTIVE_POWERUSAGE,
     SENSOR_AMBIENT,
     SENSOR_APPARENT_POWERUSAGE,
     SENSOR_BATTERY,
     SENSOR_CCT,
+    SENSOR_CF1,
+    SENSOR_CF2_5,
+    SENSOR_CF10,
     SENSOR_CO2,
     SENSOR_COLOR_BLUE,
     SENSOR_COLOR_GREEN,
     SENSOR_COLOR_RED,
     SENSOR_CURRENT,
+    SENSOR_CURRENTNEUTRAL,
     SENSOR_DEWPOINT,
     SENSOR_DISTANCE,
     SENSOR_ECO2,
+    SENSOR_ENERGY,
     SENSOR_FREQUENCY,
     SENSOR_HUMIDITY,
     SENSOR_ILLUMINANCE,
@@ -46,6 +55,7 @@ from .const import (
     SENSOR_PB2_5,
     SENSOR_PB5,
     SENSOR_PB10,
+    SENSOR_PHASEANGLE,
     SENSOR_PM1,
     SENSOR_PM2_5,
     SENSOR_PM10,
@@ -54,6 +64,8 @@ from .const import (
     SENSOR_PRESSURE,
     SENSOR_PRESSUREATSEALEVEL,
     SENSOR_PROXIMITY,
+    SENSOR_REACTIVE_ENERGYEXPORT,
+    SENSOR_REACTIVE_ENERGYIMPORT,
     SENSOR_REACTIVE_POWERUSAGE,
     SENSOR_SPEED,
     SENSOR_TEMPERATURE,
@@ -139,6 +151,7 @@ SENSOR_UNIT_MAP = {
     SENSOR_APPARENT_POWERUSAGE: ELECTRICAL_VOLT_AMPERE,
     SENSOR_BATTERY: PERCENTAGE,
     SENSOR_CURRENT: ELECTRICAL_CURRENT_AMPERE,
+    SENSOR_CURRENTNEUTRAL: ELECTRICAL_CURRENT_AMPERE,
     SENSOR_DISTANCE: LENGTH_CENTIMETERS,
     SENSOR_FREQUENCY: FREQUENCY_HERTZ,
     SENSOR_HUMIDITY: PERCENTAGE,
@@ -153,15 +166,25 @@ SENSOR_UNIT_MAP = {
     SENSOR_PM1: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
     SENSOR_PM2_5: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
     SENSOR_PM10: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    SENSOR_CF1: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    SENSOR_CF2_5: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    SENSOR_CF10: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    SENSOR_PHASEANGLE: DEGREE,
     SENSOR_POWERFACTOR: "Cos φ",
     SENSOR_POWERUSAGE: POWER_WATT,
     SENSOR_TOTAL_START_TIME: " ",
+    SENSOR_ACTIVE_POWERUSAGE: POWER_WATT,
     SENSOR_REACTIVE_POWERUSAGE: "VAr",
     SENSOR_TODAY: ENERGY_KILO_WATT_HOUR,
     SENSOR_TOTAL: ENERGY_KILO_WATT_HOUR,
     SENSOR_VOLTAGE: VOLT,
     SENSOR_WEIGHT: MASS_KILOGRAMS,
     SENSOR_YESTERDAY: ENERGY_KILO_WATT_HOUR,
+    SENSOR_ENERGY: ENERGY_KILO_WATT_HOUR,
+    SENSOR_ACTIVE_ENERGYEXPORT: ENERGY_KILO_WATT_HOUR,
+    SENSOR_ACTIVE_ENERGYIMPORT: ENERGY_KILO_WATT_HOUR,
+    SENSOR_REACTIVE_ENERGYEXPORT: "kVArh",
+    SENSOR_REACTIVE_ENERGYIMPORT: "kVArh",
     SENSOR_CO2: CONCENTRATION_PARTS_PER_MILLION,
     SENSOR_ECO2: CONCENTRATION_PARTS_PER_MILLION,
     SENSOR_TVOC: CONCENTRATION_PARTS_PER_BILLION,
